@@ -108,7 +108,7 @@ dualpathWideSparse <- function(y, D, x=NULL, approx=FALSE, maxsteps=2000,
         a = backsolveSparse(x,y)
         b = backsolveSparse(x,Ds)
         shits = Sign(a)
-        hits = a/(b+shits);
+        hits = a/(b+shits)
 
         # Make sure none of the hitting times are larger
         # than the current lambda (precision issue)
@@ -249,3 +249,4 @@ dualpathWideSparse <- function(y, D, x=NULL, approx=FALSE, maxsteps=2000,
   return(list(lambda=lams,beta=NA,fit=NA,u=u,hit=h,df=df,y=NA,
               completepath=completepath,bls=NA,pathobjs=pathobjs))
 }
+
