@@ -10,8 +10,8 @@ maketri3 <- function(y,D1,D2,R,q) {
   # The full D
   D = rbind(D1,D2)
   m1 = nrow(D)
-  
-  a = .C("maketri3",
+
+  a = .C(C_maketri3,
     y=as.double(y),
     D=as.double(D),
     R=as.double(R),
@@ -19,8 +19,7 @@ maketri3 <- function(y,D1,D2,R,q) {
     m2=as.integer(m2),
     n=as.integer(n),
     q=as.integer(q),
-    dup=FALSE,
-    package="genlasso")
+    PACKAGE="genlasso")
 
   y = a$y
   D = matrix(a$D,nrow=m1)
@@ -29,6 +28,6 @@ maketri3 <- function(y,D1,D2,R,q) {
   # Form D1,D2
   D1 = D[Seq(1,m2),,drop=FALSE]
   D2 = D[Seq(m2+1,m1),,drop=FALSE]
-  
+
   return(list(y=y,D1=D1,D2=D2,R=R))
 }
